import bodyParser from "body-parser";
import {
  deleteOneOrder,
  getAllOrder,
  getOrders,
  getSingleOrder,
  getUserSelf,
  updateOrderStatusById,
} from "./PosorderController.js";
import { isAuthenticatedUser, authorizeRoles } from "../../middlewares/auth.js";
import express from "express";
import {
  createOrderCheckout,
} from "./PosCheckoutController.js";
import { checkout, getRzpKey, paymentVerification } from "./PosRazerPayCheckoutController.js";

const app = express();

// Configure bodyParser to parse the raw request body as a buffer
app.use(bodyParser.raw({ type: "application/json" }));


const router = express.Router();
//checkout Routes-------------------------//
router.route("/pos-checkout/").post(isAuthenticatedUser, createOrderCheckout);
// ---------------------------------------------------

// --------------------------------------------------
//get user self
router.route("/user/self").get(isAuthenticatedUser, getUserSelf);

//admin route
router
  .route("/pos-getAll/:status")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getAllOrder);
router
  .route("/pos-getAll/")
  .get(isAuthenticatedUser, authorizeRoles("admin"), getOrders);
router.route("/pos-getOne/:id").get(isAuthenticatedUser, getSingleOrder);
router
  .route("/pos-change/status/:id")
  .patch(isAuthenticatedUser, authorizeRoles("admin"), updateOrderStatusById);

router
  .route("/pos-delete/:id")
  .delete(isAuthenticatedUser, authorizeRoles("admin"), deleteOneOrder);
//RAZERPAY checkout
router.route("/getRzpKey/:name/:email").get(isAuthenticatedUser, getRzpKey);
router.route("/Rzpcheckout/").post(isAuthenticatedUser, checkout);
router.route("/paymentverification").post(paymentVerification);
export default router;
